"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const compile_1 = require("./compile");
function getExpected(filename) {
    return fs_1.default.readFileSync("./src/expected/" + filename + ".ts").toString();
}
describe("compileBSON", () => {
    test(`JSON types`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: ["_id"],
            properties: {
                _id: {
                    type: "string",
                    minLength: 8,
                    maxLength: 8,
                    description: "String (min 8, max 8, alphanumeric pattern)",
                    pattern: "^[a-zA-Z0-9]*$",
                },
                string: {
                    description: "String",
                    type: "string",
                },
                number: {
                    description: "Number",
                    type: "number",
                },
                boolean: {
                    description: "Boolean",
                    type: "boolean",
                },
                null: {
                    description: "Null",
                    type: "null",
                },
                multipleTypes1: {
                    description: "Multiple types: string",
                    type: ["string"],
                },
                multipleTypes2: {
                    description: "Multiple types: string, number",
                    type: ["string", "number"],
                },
                multipleTypes3: {
                    description: "Multiple types: string, number, boolean",
                    type: ["string", "number", "boolean"],
                },
                multipleTypes4: {
                    description: "Multiple types: string, number, boolean, null",
                    type: ["string", "number", "boolean", "null"],
                },
            },
        };
        expect(yield compile_1.compileBSON(schema)).toBe(getExpected("json-types"));
    }));
    test(`BSON types`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: ["_id"],
            properties: {
                _id: {
                    bsonType: "string",
                    minLength: 8,
                    maxLength: 8,
                    description: "String (min 8, max 8, alphanumeric pattern)",
                    pattern: "^[a-zA-Z0-9]*$",
                },
                string: {
                    description: "String",
                    bsonType: "string",
                },
                number: {
                    description: "Number",
                    bsonType: "number",
                },
                boolean: {
                    description: "Boolean",
                    bsonType: "bool",
                },
                null: {
                    description: "Null",
                    bsonType: "null",
                },
                date: {
                    description: "Date",
                    bsonType: "date",
                },
                multipleTypes1: {
                    description: "Multiple types: string",
                    bsonType: ["string"],
                },
                multipleTypes2: {
                    description: "Multiple types: string, number",
                    bsonType: ["string", "number"],
                },
                multipleTypes3: {
                    description: "Multiple types: string, number, boolean",
                    bsonType: ["string", "number", "bool"],
                },
                multipleTypes4: {
                    description: "Multiple types: string, number, boolean, null",
                    bsonType: ["string", "number", "bool", "null"],
                },
                multipleTypes5: {
                    description: "Multiple types: string, number, boolean, null, date",
                    bsonType: ["string", "number", "bool", "null", "date"],
                },
            },
        };
        expect(yield compile_1.compileBSON(schema)).toBe(getExpected("bson-types"));
    }));
    test(`BSON types with imports - 1`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: [],
            properties: {
                string: {
                    description: "String",
                    bsonType: "string",
                },
                number: {
                    description: "Number",
                    bsonType: "number",
                },
                boolean: {
                    description: "Boolean",
                    bsonType: "bool",
                },
                null: {
                    description: "Null",
                    bsonType: "null",
                },
                date: {
                    description: "Date",
                    bsonType: "date",
                },
                decimal: {
                    description: "Decimal",
                    bsonType: "decimal",
                },
            },
        };
        expect(yield compile_1.compileBSON(schema)).toBe(getExpected("bson-types-with-imports-1"));
    }));
    test(`BSON types with imports - 2`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: [],
            properties: {
                multipleTypes1: {
                    description: "Multiple types: string",
                    type: ["string"],
                },
                multipleTypes2: {
                    description: "Multiple types: string, number",
                    type: ["string", "number"],
                },
                multipleTypes3: {
                    description: "Multiple types: string, number, boolean",
                    type: ["string", "number", "boolean"],
                },
                multipleTypes4: {
                    description: "Multiple types: string, number, boolean, null",
                    type: ["string", "number", "boolean", "null"],
                },
                multipleTypes5: {
                    description: "Multiple types: string, number, boolean, null, date",
                    bsonType: ["string", "number", "bool", "null", "date"],
                },
                multipleTypes6: {
                    description: "Multiple types: string, number, boolean, null, date, decimal",
                    bsonType: ["string", "number", "bool", "null", "date", "decimal"],
                },
            },
        };
        expect(yield compile_1.compileBSON(schema)).toBe(getExpected("bson-types-with-imports-2"));
    }));
});
describe("compileBSON with banner comments", () => {
    test(`custom banner comment`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: ["_id"],
            properties: {
                string: {
                    description: "String",
                    bsonType: "string",
                },
            },
        };
        expect(yield compile_1.compileBSON(schema, { bannerComment: ["/* Custom banner */"] })).toBe(getExpected("bson-types-with-banner"));
    }));
    test(`custom banner comment and imports`, () => __awaiter(void 0, void 0, void 0, function* () {
        const schema = {
            title: "UserDoc",
            description: "User object",
            bsonType: "object",
            additionalProperties: false,
            required: ["_id"],
            properties: {
                decimal: {
                    description: "Decimal",
                    bsonType: "decimal",
                },
            },
        };
        expect(yield compile_1.compileBSON(schema, { bannerComment: ["/* Custom banner */"] })).toBe(getExpected("bson-types-with-imports-and-banner"));
    }));
});
//# sourceMappingURL=compile.test.js.map